function [DROP_NAME] = final_dropped_channels(cf, st, freqlabel, freqname)
% identifies and prints dropped channels in correlator report string format
% input:
%   cf ... struct of control file informations
%   st ... hops 1 letter code
%   freqlabel ... frequency label cell
%   freqname ... frequency name
%
% output:
%   DROP_NAME ... dropped channels in the correct correlator report string
%   format

% pre-allocate
DROP_NAME = '';

% check if channels have been dropped for S/X-band
if isfield(cf, st)
    
    % pre-allocate
    DROP = {};
    
    % loop over frequency bands
    for iband = ['S','X']
        
        % identifiy dropped channels
        drop = identify_dropped_channels(cf,st,iband,freqlabel);
        
        % gather dropped channels
        DROP = [DROP, drop];
        
    end
    
    % convert to correlator report channel label
    
    % concetenate S and X band for freqlabel
    FREQLABEL = [freqlabel.S, freqlabel.X];
    
    % concetenate S and X band for freqname
    FREQNAME = [freqname.S, freqname.X];
    
    % loop over dropped channels
    for id = 1:length(DROP)
        
        % current drop
        d = DROP{id};
        
        % find corresponding freqname
        fqn = FREQNAME{strcmp(d,FREQLABEL)};
        
        % check for first entry
        if isempty(DROP_NAME)
            % first entry is raw freq name
            DROP_NAME = fqn;
        else
            % use ',' to seperate freq names
            DROP_NAME = [DROP_NAME,',',fqn];
        end
        
    end
    
end

end

