function [drop] = identify_dropped_channels(cf,st,iband,freqlabel)
% identifiy dropped channels via frequency channel specification in control
% file
%
% input:
%   cf ... cell with control file parameters
%   st ... hops 1 letter code
%   iband ... frequency band
%   freqlabel ... fourfit frequency labels
%
% output:
%   drop ... struct with dropped channels per frequency band

% preallocation
drop = {};

% number of dropped channels
Nd = 1;

% check if frequency band specification exist in cf file
if isfield(cf.(st),iband)
    
    % check if "freqs" keyword exists in cf file
    if isfield(cf.(st).(iband), 'freqs')
        
        % fringe-fitting freq configuration
        freqs = cf.(st).(iband).freqs;
        
        % compare existing with default channels
        for iCh = 1:length(freqlabel.(iband))
            
            % current freq label
            fl = freqlabel.(iband){iCh};
            
            % check if freq exists
            if ~strcmp(fl,freqs)
                drop(Nd) = {fl};
                Nd = Nd +1;
            end
            
        end
    end
end

end

