function [s] = parse_fourfit_control_file(f)
% parses the fourfit control file
%
% input:
%   f ... fourfit control file

% file opener
fid = fopen(f);

% check file existence
if fid<0
    warning('Cannot find fourfit control file: %s\n', f)
end

% creat struct
s = struct;

%% read file line by line
% first line
tline = strtrim(fgetl(fid));

% loop through all lines
while ischar(tline)
    
    % set if flag
    if_flag = 0;
    

    
    % print line
    disp(tline)
    
    % check for non-empty line
    if ~isempty(tline)
        
        % check for comment line
        if ~strcmp(tline(1),'*')
            
            % check for if block
            if ~strcmp(tline(1:2),'if')
                %% global settings
                
                % convert line to cell
                C = textscan(tline,'%s');
                
                % pc_mode
                if strfind(tline,'pc_mode')
                    s.pc_mode = C{1,1}{2};
                end
                
                % pc_period
                if strfind(tline,'pc_period')
                    s.pc_period = C{1,1}{2};
                end
                
                % sb_win
                if strfind(tline,'sb_win')
                    s.sb_win = [str2double(C{1,1}{2}),str2double(C{1,1}{3})];
                end
                
                % mb_win
                if strfind(tline,'mb_win')
                    s.mb_win = [str2double(C{1,1}{2}),str2double(C{1,1}{3})];
                end
                
                % dr_win
                if strfind(tline,'dr_win')
                    s.dr_win = [str2double(C{1,1}{2}),str2double(C{1,1}{3})];
                end
                
                % weak_channel
                if strfind(tline,'weak_channel')
                    s.weak_channel = C{1,1}{2};
                end
                
            else
                %% if block
                
                % convert line to cell
                C = textscan(tline,'%s');
    
                % find station
                i = find(strcmp('station',C{1,1}));

                % station name
                if ~isempty(i)
                    sn = C{1,1}{i+1,1};
                else
                    sn = 'station_independent';
                end

                % find fgroup
                j = find(strcmp('f_group',C{1,1}));

                % fgroup
                if ~isempty(j)
                    fgroup = C{1,1}{j+1,1};
                else
                    fgroup = 'fgroup_independent';
                end

                % next line
                tline = strtrim(fgetl(fid));
                
                if ~isempty(tline)
                
                    % look insight if block
                    while ~strcmp(tline(1:2),'if')

                        % convert line to cell
                        C = textscan(tline,'%s');

                        % check if its a pc_mode line
                        i = find(strcmp(C{1,1},'pc_mode'));

                        % get pc_mode
                        if ~isempty(i)
                            pc_mode = C{1,1}{i+1,1};
                            
                            % store pc_mode to value
                            s.(sn).(fgroup).pc_mode = pc_mode;
                        else
                            pc_mode = [];
                        end
                        
                        % check if its a freqs line
                        i = find(strcmp(C{1,1},'freqs'));

                        % get freqs
                        if ~isempty(i)
                            freqs = C{1,1}(i+1:length(C{1,1}),1);
                            % store pc_mode to value
                            s.(sn).(fgroup).freqs = freqs;
                        else
                            freqs = [];
                        end
                        
                        % pc_phases
                        i = find(strcmp(C{1,1},'pc_phases'));
                        
                        % get pc_phases
                        if ~isempty(i)
                            pc_phases = C{1,1}(i+1:length(C{1,1}),1);
                            % store pc_mode to value
                            s.(sn).(fgroup).pc_phases = pc_phases;
                        else
                            pc_phases = [];
                        end                        
                        
                        % next line
                        tline = fgetl(fid);
                        if ischar(tline)
                            tline = strtrim(tline);
                        end

                        % check for non-empty line
                        if isempty(tline)
                            tline = blanks(10);
                        end
                        
                        % convert to char
                        if ~ischar(tline)
                            return;
                        end
                        
                        % flag
                        if_flag = 1;
                    end
                end
            end
        end
    end
    
    % check it comes straight from if block
    if if_flag == 0
        tline = fgetl(fid);
        if ischar(tline)
            tline = strtrim(tline);
        end
    end
    
end

fclose(fid);


